# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Test-Base
Version:	0.89
Release:	16.%{__distinit}%{__distvers}
Summary:	Data Driven Testing Framework
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Base
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Base-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# Module Runtime
BuildRequires:	perl(Algorithm::Diff) >= 1.15
BuildRequires:	perl(Carp)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(Filter::Util::Call)
BuildRequires:	perl(LWP::Simple)
BuildRequires:	perl(MIME::Base64)
BuildRequires:	perl(Scalar::Util) >= 1.07
BuildRequires:	perl(Spiffy) >= 0.40
BuildRequires:	perl(strict)
BuildRequires:	perl(Test::Deep)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Text::Diff) >= 0.35
BuildRequires:	perl(warnings)
BuildRequires:	perl(YAML)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::Tester)
# Release Tests
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Algorithm::Diff) >= 1.15
Requires:	perl(Data::Dumper)
Requires:	perl(File::Path)
Requires:	perl(Filter::Util::Call)
Requires:	perl(LWP::Simple)
Requires:	perl(MIME::Base64)
Requires:	perl(Scalar::Util) >= 1.07
Requires:	perl(Test::Deep)
Requires:	perl(Test::More) >= 0.88
Requires:	perl(Text::Diff) >= 0.35
Requires:	perl(YAML)

%description
Testing is usually the ugly part of Perl module authoring. Perl gives you a
standard way to run tests with Test::Harness, and basic testing primitives
with Test::More. After that you are pretty much on your own to develop a
testing framework and philosophy. Test::More encourages you to make your
own framework by subclassing Test::Builder, but that is not trivial.

Test::Base gives you a way to write your own test framework base class that
*is* trivial.

%prep
%setup -q -n Test-Base-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test RELEASE_TESTING=1

%files
%license LICENSE
%doc Changes CONTRIBUTING README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Base.3*
%{_mandir}/man3/Test::Base::Filter.3*

%changelog
* Sat Jul  1 2023 Paul Howarth <paul@city-fan.org> - 0.89-16
- Use SPDX-format license tag
- Use %%license unconditionally

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 0.89-5
- Perl 5.30 rebuild

* Fri Apr 20 2018 Paul Howarth <paul@city-fan.org> - 0.89-1
- Update to 0.89
  - Require Test::More ≥ 0.88 (GH#19)
  - Support the use of plain 'use Test::Base' without any tests (GH#21)

* Wed Apr 11 2018 Paul Howarth <paul@city-fan.org> - 0.88-10
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Wed Sep 28 2016 Paul Howarth <paul@city-fan.org> - 0.88-6
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 10 2014 Paul Howarth <paul@city-fan.org> - 0.88-2
- Perl 5.20 rebuild

* Tue Aug 26 2014 Paul Howarth <paul@city-fan.org> - 0.88-1
- Update to 0.88
  - Add t/000-require-modules.t
  - Eliminate File::Basename from test/
  - Eliminate spurious trailing whitespace
  - Meta 0.0.2
  - Fix Meta error (s/zild/=zild/)
  - Unbundle Module::Install::TestBase
  - Fix failing t/diff_is.t (Issue/15)
  - Replace tabs with spaces
- Drop dependency filter for Module::Install::TestBase, no longer needed
- Add patch to support building with Test::More < 0.88

* Sat Aug  9 2014 Paul Howarth <paul@city-fan.org> - 0.79-1
- Update to 0.79
  - Change Provider test to use string eval, keeping it out of the eyes of
    Perl::Prereqs
  - Fix swim errors
  - Dep on EU::MM 6.52

* Thu Aug  7 2014 Paul Howarth <paul@city-fan.org> - 0.76-1
- Update to 0.76
  - Switch to Zilla-Dist
  - Add Algorithm::Diff and Text::Diff to test.requires
  - Fix copyright years
  - Remove (c) from Copyright
  - Switch docs to Swim
  - Add badges to docs
  - PR/11 and fixes
  - Add $VERSION back into Test::Base
  - Applied PR/4 from schwern++
  - Dep on new Spiffy-0.40 to get rid of warnings on blead 5.21.x
  - Use PR/14 which makes old and new Test::Builders work
  - Fix bad encoding in Pod
- Use %%license where possible
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Drop test hack for perl 5.8.5
  - Drop support for building with ExtUtils::MakeMaker < 6.30
  - Drop support for building with Test::More < 0.62

* Tue Feb 11 2014 Paul Howarth <paul@city-fan.org> - 0.62-1
- Update to 0.62
  - Fix bad skip counts in tests

* Mon Feb 10 2014 Paul Howarth <paul@city-fan.org> - 0.61-1
- Update to 0.61
  - Switch to dzil
- Package upstream's LICENSE file
- Add patch to support building with ExtUtils::MakeMaker < 6.30

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 0.60-8
- Perl 5.18 rebuild

* Mon Apr  1 2013 Paul Howarth <paul@city-fan.org> - 0.60-5
- Fix requires filter

* Fri Jul  6 2012 Paul Howarth <paul@city-fan.org> - 0.60-4
- BR: perl(base), perl(Cwd), perl(File::Spec) and perl(lib)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop patch enabling build with perl < 5.8.3
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Sep 26 2011 Paul Howarth <paul@city-fan.org> - 0.60-3
- Import from Fedora

* Wed Jun 29 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.60-2
- Perl mass rebuild

* Sat May 14 2011 Iain Arnell <iarnell@gmail.com> - 0.60-1
- Update to latest upstream version
- Clean up spec for modern rpmbuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.59-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.59-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Mon Dec 13 2010 Steven Pritchard <steve@kspei.com> - 0.59-1
- Update to 0.59

* Thu May 06 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.58-4
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.58-3
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.58-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun May 17 2009 Steven Pritchard <steve@kspei.com> - 0.58-1
- Update to 0.58
- BR Test::Deep and Test::Tester

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.55-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Dec 10 2008 Steven Pritchard <steve@kspei.com> - 0.55-1
- Update to 0.55
- Explicitly BR Test::More >= 0.62
- BR YAML

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.54-3
- Rebuild for new perl

* Sat Jul 07 2007 Steven Pritchard <steve@kspei.com> - 0.54-2
- BR Test::More

* Mon Jul 02 2007 Steven Pritchard <steve@kspei.com> - 0.54-1
- Update to 0.54

* Wed Apr 18 2007 Steven Pritchard <steve@kspei.com> - 0.53-2
- BR ExtUtils::MakeMaker

* Sat Dec 09 2006 Steven Pritchard <steve@kspei.com> - 0.53-1
- Update to 0.53
- Use fixperms macro instead of our own chmod incantation

* Sat Sep 16 2006 Steven Pritchard <steve@kspei.com> - 0.52-2
- Fix find option order

* Sat Jul 01 2006 Steven Pritchard <steve@kspei.com> - 0.52-1
- Update to 0.52

* Mon May 08 2006 Steven Pritchard <steve@kspei.com> - 0.50-2
- Add explicit dependencies for Text::Diff and LWP::Simple

* Thu May 04 2006 Steven Pritchard <steve@kspei.com> - 0.50-1
- Specfile autogenerated by cpanspec 1.65
- Remove explicit BR: perl and Requires: perl(Spiffy)
